@@ -29,15 +29,15 @@ class PGFunction(ReplaceableEntity):
 
     def to_sql_statement_create(self) -> str:
         """ Generates a SQL "create function" statement for PGFunction """
-        return f"CREATE FUNCTION {self.schema}.{self.signature} {self.definition}"
+        return sql_text(f"CREATE FUNCTION {self.schema}.{self.signature} {self.definition}")
 
     def to_sql_statement_drop(self) -> str:
         """ Generates a SQL "drop function" statement for PGFunction """
-        return f"DROP FUNCTION {self.schema}.{self.signature}"
+        return sql_text(f"DROP FUNCTION {self.schema}.{self.signature}")
 
     def to_sql_statement_create_or_replace(self) -> str:
         """ Generates a SQL "create or replace function" statement for PGFunction """
-        return f"CREATE OR REPLACE FUNCTION {self.schema}.{self.signature} {self.definition}"
+        return sql_text(f"CREATE OR REPLACE FUNCTION {self.schema}.{self.signature} {self.definition}")
 
     @classmethod
     def from_database(cls, connection, schema="%") -> List[PGFunction]:
