@@ -32,15 +32,15 @@ class PGView(ReplaceableEntity):
 
     def to_sql_statement_create(self) -> str:
         """Generates a SQL "create view" statement"""
-        return f"CREATE VIEW {self.schema}.{self.signature} AS {self.definition}"
+        return sql_text(f"CREATE VIEW {self.schema}.{self.signature} AS {self.definition}")
 
     def to_sql_statement_drop(self) -> str:
         """Generates a SQL "drop view" statement"""
-        return f"DROP VIEW {self.schema}.{self.signature}"
+        return sql_text(f"DROP VIEW {self.schema}.{self.signature}")
 
     def to_sql_statement_create_or_replace(self) -> str:
         """Generates a SQL "create or replace view" statement"""
-        return f"CREATE OR REPLACE VIEW {self.schema}.{self.signature} AS {self.definition}"
+        return sql_text(f"CREATE OR REPLACE VIEW {self.schema}.{self.signature} AS {self.definition}")
 
     @classmethod
     def from_database(cls, connection, schema="%") -> List[PGView]:
